@@ -15,12 +15,18 @@ omitMostMissing <- function(grp, omit) {
 	if (omit == 0) return(grp)
 
 	exclude <- order(-nacount)[1:omit]
-	excol <- colnames(grp$data)[exclude]
+	excol <- colnames(data)[exclude]
 	imask <- -match(excol, colnames(grp$param))
 	grp$spec <- grp$spec[imask]
 	grp$param <- grp$param[,imask]
 	grp$free <- grp$free[,imask]
-	grp$data <- grp$data[,-match(excol, colnames(grp$data))]
+	grp$data <- data[,-match(excol, colnames(data))]
+	if (!is.null(grp$weightColumn)) {
+		grp$data <- compressDataFrame(grp$data)
+	}
+	if (!is.null(grp$observedStats)) {
+		grp$observedStats <- nrow(grp$data)
+	}
 	grp$omitted <- c(grp$omitted, excol)
 	grp
 }
@@ -206,6 +212,20 @@ print.summary.itemOutcomeBySumScore <- function(x,...) {
 
 ##' Compute EAP scores
 ##'
+##' If you have missing data then you must specify
+##' \code{minItemsPerScore}.  This option will set scores to NA when
+##' there are too few items to make an accurate score estimate.  If
+##' you are using the scores as point estimates without considering
+##' the standard error then you should set \code{minItemsPerScore} as
+##' high as you can tolerate. This will increase the amount of missing
+##' data but scores will be more accurate. If you are carefully
+##' considering the standard errors of the scores then you can set
+##' \code{minItemsPerScore} to 1. This will mimic the behavior of most
+##' other IFA software wherein scores are estimated if there is at
+##' least 1 non-NA item for the score. However, it may make more sense
+##' to set \code{minItemsPerScore} to 0. When set to 0, all NA rows
+##' are scored to the prior distribution.
+##'
 ##' @param grp a list with spec, param, and data
 ##' @param ...  Not used.  Forces remaining arguments to be specified by name.
 ##' @param naAction deprecated, will be removed in the next release
